==> material-ui-shell-1.0.5.tgz: package/es/containers/SelectableMenuList/SelectableMenuList.js <==
var _this = this,
    _jsxFileName = "C:\\github\\os\\react-most-wanted\\packages\\material-ui-shell\\src\\containers\\SelectableMenuList\\SelectableMenuList.js";

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import ArrowBack from '@material-ui/icons/ArrowBack';
import Divider from '@material-ui/core/Divider';
import IconButton from '@material-ui/core/IconButton';
import KeyboardArrowRight from '@material-ui/icons/KeyboardArrowRight';
import List from '@material-ui/core/List';
import ListItem from '@material-ui/core/ListItem';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemSecondaryAction from '@material-ui/core/ListItemSecondaryAction';
import ListItemText from '@material-ui/core/ListItemText';
import PropTypes from 'prop-types';
import React, { Component, useState } from 'react';

var SelectableMenuList = function SelectableMenuList(_ref) {
  var onIndexChange = _ref.onIndexChange,
      useMinified = _ref.useMinified,
      items = _ref.items,
      index = _ref.index;

  var _useState = useState({}),
      state = _useState[0],
      setState = _useState[1];

  var handleNestedItemsClick = function handleNestedItemsClick(item) {
    if (item.nestedItems) {
      var previousItems = state.previousItems || [];
      var _items = item.nestedItems;
      var title = item.primaryText;
      previousItems.unshift(state.items || _items);
      setState(_extends(_extends({}, state), {}, {
        items: _items,
        previousItems,
        title,
        index: item.value
      }));
    } else {
      if (item.value || item.onClick) {
        setState(_extends(_extends({}, state), {}, {
          index: item.value
        }));
      }
    }
  };

  var handleBackClick = function handleBackClick() {
    var previousItems = state.previousItems || [];
    var items = previousItems[0] || undefined;
    previousItems.shift();
    setState(_extends(_extends({}, state), {}, {
      items,
      previousItems
    }));
  };

  var getNestedItems = function getNestedItems(hostItem, hostIndex) {
    if (hostItem.nestedItems !== undefined) {
      var _items2 = hostItem.nestedItems.filter(function (item) {
        return item.visible !== false;
      });

      if (_items2.length > 0) {
        return _items2.map(function (item, i) {
          return getItem(item, hostIndex.toString() + i.toString());
        });
      }
    }

    return null;
  };

  var getItem = function getItem(item, i) {
    var index = state.index;
    delete item.visible;

    if (item !== undefined) {
      if (item.subheader !== undefined) {
        return /*#__PURE__*/React.createElement("div", {
          key: i,
          inset: item.inset,
          style: item.style,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 71,
            columnNumber: 11
          }
        }, item.subheader);
      } else if (item.divider !== undefined) {
        return /*#__PURE__*/React.createElement(Divider, {
          key: i,
          inset: item.inset,
          style: item.style,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 76,
            columnNumber: 16
          }
        });
      } else {
        return /*#__PURE__*/React.createElement(ListItem, {
          button: true,
          selected: index && index === item.value,
          key: i,
          onClick: function onClick(e) {
            onIndexChange(e, item.value);
            handleNestedItemsClick(item);

            if (item.onClick) {
              item.onClick();
            }
          },
          onMouseDown: function onMouseDown(e) {
            if (e.button === 1) {
              var win = window.open("" + item.value, '_blank');
              win.focus();
            }
          },
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 79,
            columnNumber: 11
          }
        }, item.leftIcon && /*#__PURE__*/React.createElement(ListItemIcon, {
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 98,
            columnNumber: 31
          }
        }, item.leftIcon), !useMinified && /*#__PURE__*/React.createElement(ListItemText, {
          primary: item.primaryText,
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 100,
            columnNumber: 30
          }
        }), item.nestedItems && !useMinified && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
          onClick: function onClick() {
            handleNestedItemsClick(item);
          },
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 103,
            columnNumber: 15
          }
        }, /*#__PURE__*/React.createElement(IconButton, {
          style: {
            marginRight: useMinified ? 150 : undefined
          },
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 108,
            columnNumber: 17
          }
        }, /*#__PURE__*/React.createElement(KeyboardArrowRight, {
          color: 'action',
          __self: _this,
          __source: {
            fileName: _jsxFileName,
            lineNumber: 111,
            columnNumber: 19
          }
        }))));
      }
    }

    return null;
  };

  var list = state.previousItems && state.previousItems.length > 0 ? state.items : items;
  return /*#__PURE__*/React.createElement(List, {
    value: index,
    onChange: onIndexChange,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 127,
      columnNumber: 5
    }
  }, state.items && state.previousItems && state.previousItems.length > 0 && /*#__PURE__*/React.createElement("div", {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 129,
      columnNumber: 9
    }
  }, /*#__PURE__*/React.createElement(ListItem, {
    button: true,
    onClick: function onClick() {
      handleBackClick();
    },
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 130,
      columnNumber: 11
    }
  }, /*#__PURE__*/React.createElement(ListItemIcon, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 136,
      columnNumber: 13
    }
  }, /*#__PURE__*/React.createElement(ArrowBack, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 137,
      columnNumber: 15
    }
  })), /*#__PURE__*/React.createElement(ListItemText, {
    primary: state.title,
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 139,
      columnNumber: 13
    }
  })), /*#__PURE__*/React.createElement(Divider, {
    __self: _this,
    __source: {
      fileName: _jsxFileName,
      lineNumber: 141,
      columnNumber: 11
    }
  })), list.filter(function (item) {
    return item.visible !== false;
  }).map(function (item, i) {
    return getItem(item, i);
  }));
};

SelectableMenuList.propTypes = process.env.NODE_ENV !== "production" ? {
  items: PropTypes.array.isRequired,
  onIndexChange: PropTypes.func.isRequired,
  index: PropTypes.string.isRequired
} : {};
export default SelectableMenuList;

==> material-ui-shell-1.1.4.tgz: package/es/containers/SelectableMenuList/SelectableMenuList.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

import ArrowBack from '@material-ui/icons/ArrowBack';
import Divider from '@material-ui/core/Divider';
import IconButton from '@material-ui/core/IconButton';
import KeyboardArrowRight from '@material-ui/icons/KeyboardArrowRight';
import List from '@material-ui/core/List';
import ListItem from '@material-ui/core/ListItem';
import ListItemIcon from '@material-ui/core/ListItemIcon';
import ListItemSecondaryAction from '@material-ui/core/ListItemSecondaryAction';
import ListItemText from '@material-ui/core/ListItemText';
import PropTypes from 'prop-types';
import React, { Component, useState, useEffect } from 'react';

var SelectableMenuList = function SelectableMenuList(_ref) {
  var onIndexChange = _ref.onIndexChange,
      useMinified = _ref.useMinified,
      items = _ref.items,
      index = _ref.index;

  var _useState = useState({}),
      state = _useState[0],
      setState = _useState[1]; //Clears nested state if the root items change
  //Used to open auth menu if we are in a nested menu


  useEffect(function () {
    setState({});
  }, [items]);

  var handleNestedItemsClick = function handleNestedItemsClick(item) {
    if (item.nestedItems) {
      var previousItems = state.previousItems || [];
      var previousTitles = state.previousTitles || [];
      var _items = item.nestedItems;
      var title = item.primaryText;
      previousItems.unshift(state.items || _items);
      previousTitles.unshift(state.title || title);
      setState(_extends(_extends({}, state), {}, {
        items: _items,
        previousItems,
        previousTitles,
        title,
        index: item.value
      }));
    } else {
      if (item.value || item.onClick) {
        setState(_extends(_extends({}, state), {}, {
          index: item.value
        }));
      }
    }
  };

  var handleBackClick = function handleBackClick() {
    var previousItems = state.previousItems || [];
    var previousTitles = state.previousTitles || [];
    var items = previousItems[0] || undefined;
    var title = previousTitles[0] || undefined;
    previousItems.shift();
    previousTitles.shift();
    setState(_extends(_extends({}, state), {}, {
      items,
      previousItems,
      previousTitles,
      title
    }));
  };

  var getNestedItems = function getNestedItems(hostItem, hostIndex) {
    if (hostItem.nestedItems !== undefined) {
      var _items2 = hostItem.nestedItems.filter(function (item) {
        return item.visible !== false;
      });

      if (_items2.length > 0) {
        return _items2.map(function (item, i) {
          return getItem(item, hostIndex.toString() + i.toString());
        });
      }
    }

    return null;
  };

  var getItem = function getItem(item, i) {
    var index = state.index;
    delete item.visible;

    if (item !== undefined) {
      if (item.subheader !== undefined) {
        return /*#__PURE__*/React.createElement("div", {
          key: i,
          inset: item.inset,
          style: item.style
        }, item.subheader);
      } else if (item.divider !== undefined) {
        return /*#__PURE__*/React.createElement(Divider, {
          key: i,
          inset: item.inset,
          style: item.style
        });
      } else {
        return /*#__PURE__*/React.createElement(ListItem, {
          button: true,
          selected: index && index === item.value,
          key: i,
          onClick: function onClick(e) {
            onIndexChange(e, item.value);
            handleNestedItemsClick(item);

            if (item.onClick) {
              item.onClick();
            }
          },
          onMouseDown: function onMouseDown(e) {
            if (e.button === 1) {
              var win = window.open("" + item.value, '_blank');
              win.focus();
            }
          }
        }, item.leftIcon && /*#__PURE__*/React.createElement(ListItemIcon, null, item.leftIcon), !useMinified && /*#__PURE__*/React.createElement(ListItemText, {
          primary: item.primaryText
        }), item.nestedItems && !useMinified && /*#__PURE__*/React.createElement(ListItemSecondaryAction, {
          onClick: function onClick() {
            handleNestedItemsClick(item);
          }
        }, /*#__PURE__*/React.createElement(IconButton, {
          style: {
            marginRight: useMinified ? 150 : undefined
          }
        }, /*#__PURE__*/React.createElement(KeyboardArrowRight, {
          color: 'action'
        }))));
      }
    }

    return null;
  };

  var list = state.previousItems && state.previousItems.length > 0 ? state.items : items;
  return /*#__PURE__*/React.createElement(List, {
    value: index,
    onChange: onIndexChange
  }, state.items && state.previousItems && state.previousItems.length > 0 && /*#__PURE__*/React.createElement("div", null, /*#__PURE__*/React.createElement(ListItem, {
    button: true,
    onClick: function onClick() {
      handleBackClick();
    }
  }, /*#__PURE__*/React.createElement(ListItemIcon, null, /*#__PURE__*/React.createElement(ArrowBack, null)), /*#__PURE__*/React.createElement(ListItemText, {
    primary: state.title
  })), /*#__PURE__*/React.createElement(Divider, null)), list.filter(function (item) {
    return item.visible !== false;
  }).map(function (item, i) {
    return getItem(item, i);
  }));
};

SelectableMenuList.propTypes = process.env.NODE_ENV !== "production" ? {
  items: PropTypes.array.isRequired,
  onIndexChange: PropTypes.func.isRequired,
  index: PropTypes.string.isRequired
} : {};
export default SelectableMenuList;
